@@ -10,7 +10,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import List
 
-version = '3.1.4'
+version = '3.1.5'
 version_info = list(map(int, version.split('.')))
 
 
@@ -57,7 +57,7 @@ class ComponentType():
     Sanic = "Sanic"
     AioHttp = "AioHttp"
     Pyramid = "Pyramid"
-    CustomLog = "CustomLog"
+    CustomEvent = "CustomEvent"
     Log = "Log"
 
 
