@@ -37,12 +37,12 @@ def install():
     ):
         if log_level.get(config.log_level) <= level:
             context = get_context()
-            with context.new_local_span(op="Log") as span:
+            with context.new_exit_span(op="Log", peer='') as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
 
                 data = params_tostring(msg, level)
-                span.logs.append(Log(items=[LogItem(key="Log", val=data)]))
+                span.logs.append(Log(items=[LogItem(key=ComponentType.Log, val=data)]))
 
                 res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
 
@@ -56,12 +56,12 @@ def install():
     def _fast_py35_handle(this: logging.Logger, level, msg, args, exc_info=None, extra=None):
         if log_level.get(config.log_level) <= level:
             context = get_context()
-            with context.new_local_span(op="Log") as span:
+            with context.new_exit_span(op="Log", peer='') as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
 
                 data = params_tostring(msg, level)
-                span.logs.append(Log(items=[LogItem(key="Log", val=data)]))
+                span.logs.append(Log(items=[LogItem(key=ComponentType.Log, val=data)]))
 
                 res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
 
